Added proper device data types

Change-Id: I42029635ff68c3c13a764a3eda6447e6c77878c6


[ROCm/hip commit: 39910029a6]
This commit is contained in:
Aditya Atluri
2017-01-11 15:06:25 -06:00
vanhempi 8e219d3624
commit 4186194692
7 muutettua tiedostoa jossa 4010 lisäystä ja 774 poistoa
@@ -20,13 +20,18 @@ THE SOFTWARE.
#ifndef HIP_HCC_DETAIL_DEVICE_FUNCTIONS_H
#define HIP_HCC_DETAIL_DEVICE_FUNCTIONS_H
#include "hip_runtime.h"
#include <hip/hip_runtime.h>
#include <hip/hip_vector_types.h>
__device__ float __int_as_float (int x);
__device__ double __hiloint2double (int hi, int lo);
extern __HIP_DEVICE__ double __longlong_as_double(long long int x);
extern __HIP_DEVICE__ long long int __double_as_longlong(double x);
__device__ char4 __hip_hc_add8pk(char4, char4);
__device__ char4 __hip_hc_sub8pk(char4, char4);
__device__ char4 __hip_hc_mul8pk(char4, char4);
extern __device__ double __longlong_as_double(long long int x);
extern __device__ long long int __double_as_longlong(double x);
#endif
@@ -25,8 +25,8 @@ THE SOFTWARE.
#if __HCC__
#if __hcc_workweek__ >= 16164
#include "hip/hip_vector_types.h"
#include "hip/hcc_detail/host_defines.h"
#include "hip_vector_types.h"
#include "host_defines.h"
__device__ char __ldg(const char* );
@@ -75,4 +75,3 @@ __device__ double2 __ldg(const double2* );
#endif // __HCC__
#endif // HIP_LDG_H
@@ -46,6 +46,7 @@ THE SOFTWARE.
#define CUDA_SUCCESS hipSuccess
#include <hip/hip_runtime_api.h>
//#include "hip/hcc_detail/hip_hcc.h"
//---
// Remainder of this file only compiles with HCC
@@ -815,9 +816,6 @@ extern "C" __device__ void* __hip_hc_free(void *ptr);
//extern "C" __device__ void* malloc(size_t size);
//extern "C" __device__ void* free(void *ptr);
extern "C" __device__ char4 __hip_hc_add8pk(char4, char4);
extern "C" __device__ char4 __hip_hc_sub8pk(char4, char4);
extern "C" __device__ char4 __hip_hc_mul8pk(char4, char4);
#define __syncthreads() hc_barrier(CLK_LOCAL_MEM_FENCE)
File diff suppressed because it is too large Load Diff